@@ -4,7 +4,7 @@ Main interface for ec2 service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_ec2 import (
         BundleTaskCompleteWaiter,
         Client,
@@ -165,13 +165,10 @@ Usage::
         VpnConnectionDeletedWaiter,
     )
 
-    session = boto3.Session()
+    session = Session()
+    client: EC2Client = session.client("ec2")
 
-    client: EC2Client = boto3.client("ec2")
-    session_client: EC2Client = session.client("ec2")
-
-    resource: EC2ServiceResource = boto3.resource("ec2")
-    session_resource: EC2ServiceResource = session.resource("ec2")
+    resource: EC2ServiceResource = session.resource("ec2")
 
     bundle_task_complete_waiter: BundleTaskCompleteWaiter = client.get_waiter("bundle_task_complete")
     conversion_task_cancelled_waiter: ConversionTaskCancelledWaiter = client.get_waiter("conversion_task_cancelled")
